@@ -3,47 +3,52 @@
 <context>
     <name>Aide</name>
     <message>
-        <location filename="Ui_help.py" line="139"/>
+        <location filename="../Ui_help.py" line="144"/>
         <source>Aide</source>
-        <translation>Aide</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="138"/>
+        <location filename="../Ui_help.py" line="143"/>
         <source>Mode d&apos;emploi</source>
-        <translation>Mode d&apos;emploi</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="142"/>
+        <location filename="../Ui_help.py" line="145"/>
+        <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
+        <translation>ScolaSync, pour gérer les fichiers des baladeurs</translation>
+    </message>
+    <message>
+        <location filename="" line="5570656"/>
+        <source>Numero de version&#xa0;:</source>
+        <translation type="obsolete">Numéro de version :</translation>
+    </message>
+    <message>
+        <location filename="../Ui_help.py" line="147"/>
         <source>Auteurs</source>
-        <translation>Auteurs</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="143"/>
+        <location filename="../Ui_help.py" line="148"/>
         <source>Licence</source>
-        <translation>Licence</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="144"/>
+        <location filename="../Ui_help.py" line="149"/>
         <source>Langues et traductions</source>
-        <translation>Langues et traductions</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="145"/>
+        <location filename="../Ui_help.py" line="150"/>
         <source>A propos</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="Ui_help.py" line="146"/>
+        <location filename="../Ui_help.py" line="151"/>
         <source>Fermer</source>
-        <translation>Fermer</translation>
-    </message>
-    <message>
-        <location filename="Ui_help.py" line="140"/>
-        <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_help.py" line="141"/>
+        <location filename="../Ui_help.py" line="146"/>
         <source>Numero de version :</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,340 +56,450 @@
 <context>
     <name>Dialog</name>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="167"/>
+        <location filename="" line="5570656"/>
+        <source>Choix des fichiers &#xe0; copier</source>
+        <translation type="obsolete">Choix des fichiers à copier</translation>
+    </message>
+    <message>
+        <location filename="../Ui_copyToDialog1.py" line="175"/>
         <source>/</source>
-        <translation>/</translation>
-    </message>
-    <message>
-        <location filename="Ui_copyToDialog1.py" line="119"/>
-        <source>depuis l&apos;ordinateur</source>
-        <translation type="obsolete">depuis l&apos;ordinateur</translation>
-    </message>
-    <message>
-        <location filename="Ui_copyToDialog1.py" line="166"/>
-        <source>vers</source>
-        <translation type="obsolete">vers</translation>
-    </message>
-    <message>
-        <location filename="Ui_deleteDialog.py" line="99"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="Ui_copyToDialog1.py" line="191"/>
-        <source>Abandonner</source>
-        <translation>Abandonner</translation>
-    </message>
-    <message>
-        <location filename="Ui_copyToDialog1.py" line="192"/>
-        <source>Continuer ...</source>
-        <translation>Continuer ...</translation>
-    </message>
-    <message>
-        <location filename="Ui_deleteDialog.py" line="92"/>
-        <source>Ajouter un fichier ou un filtre</source>
-        <translation>Ajouter un fichier ou un filtre</translation>
-    </message>
-    <message>
-        <location filename="Ui_deleteDialog.py" line="95"/>
-        <source>Rechercher (fichier) ...</source>
-        <translation>Rechercher (fichier) ...</translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="chooseFromUsbDialog.py" line="42"/>
-        <source>Choix de fichiers à copier</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_copyToDialog1.py" line="166"/>
-        <source>Choix des fichiers à copier</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_copyToDialog1.py" line="184"/>
-        <source>Taille totale :</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_deleteDialog.py" line="84"/>
-        <source>Choix de fichiers à supprimer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_deleteDialog.py" line="85"/>
-        <source>Liste de fichiers à supprimer (jokers autorisés)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_deleteDialog.py" line="87"/>
-        <source>Supprimer l&apos;item sélectionné</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_deleteDialog.py" line="90"/>
-        <source>Écrire le nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_deleteDialog.py" line="98"/>
-        <source>Rechercher (répertoire) ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="168"/>
+        <location filename="../Ui_copyToDialog1.py" line="176"/>
         <source>Ordinateur</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="170"/>
+        <location filename="../Ui_copyToDialog1.py" line="178"/>
         <source>Disque dur</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="176"/>
+        <location filename="../Ui_chooseInSticks.py" line="157"/>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_copyToDialog1.py" line="184"/>
         <source>Baladeur</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="179"/>
+        <location filename="../Ui_copyToDialog1.py" line="187"/>
         <source>Disque flash</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="182"/>
+        <location filename="../Ui_copyToDialog1.py" line="190"/>
         <source>Cle USB</source>
-        <translation type="unfinished"></translation>
+        <translation>Clé USB</translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="186"/>
+        <location filename="../Ui_copyToDialog1.py" line="194"/>
         <source>Ajouter a la liste</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajouter à la liste</translation>
     </message>
     <message>
-        <location filename="Ui_copyToDialog1.py" line="189"/>
+        <location filename="../Ui_copyToDialog1.py" line="197"/>
         <source>Retirer de la liste</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_preferences.py" line="52"/>
+        <location filename="../Ui_copyToDialog1.py" line="199"/>
+        <source>Abandonner</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_copyToDialog1.py" line="200"/>
+        <source>Continuer ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="145"/>
+        <source>Double-clic non pris en compte</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="145"/>
+        <source>pas d&apos;action pour l&apos;attribut %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="265"/>
+        <source>Veuillez choisir au moins un fichier</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="261"/>
+        <source>Choix de la destination ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="292"/>
+        <source>Voir les copies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="297"/>
+        <source>Destination manquante</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="297"/>
+        <source>Veuillez choisir une destination pour la copie des fichiers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_chooseInSticks.py" line="131"/>
+        <source>Zone de recherche</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_chooseInSticks.py" line="150"/>
+        <source>Ajouter un fichier ou un filtre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_chooseInSticks.py" line="153"/>
+        <source>Rechercher (fichier) ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_preferences.py" line="57"/>
         <source>Preferences de ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="Ui_preferences.py" line="53"/>
+        <location filename="../Ui_preferences.py" line="58"/>
         <source>Preferences</source>
+        <translation>Préférences</translation>
+    </message>
+    <message>
+        <location filename="../Ui_preferences.py" line="63"/>
+        <source>Travail</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../copyToDialog1.py" line="162"/>
+        <source>%s kilo-octets</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../copyToDialog1.py" line="168"/>
+        <source>%s giga-octets</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ownedUsbDisk.py" line="160"/>
+        <source>inconnu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ownedUsbDisk.py" line="199"/>
+        <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
+        <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
+    </message>
+    <message>
+        <location filename="../ownedUsbDisk.py" line="200"/>
+        <source>Entrer un nom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="221"/>
+        <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_preferences.py" line="55"/>
+        <location filename="../Ui_chooseInSticks.py" line="130"/>
+        <source>Choix de fichiers à supprimer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="132"/>
+        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Répertoire des &lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documents de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="138"/>
+        <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="139"/>
+        <source>Le répertoire des clés où se trouvent les documents de travail</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="140"/>
+        <source>Choix de clé modèle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="142"/>
+        <source>Choisir une des clés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="143"/>
+        <source>Liste de fichiers à traiter (jokers autorisés)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="145"/>
+        <source>Supprimer l&apos;item sélectionné</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="148"/>
+        <source>Écrire le nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_chooseInSticks.py" line="156"/>
+        <source>Rechercher (répertoire) ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="60"/>
         <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_preferences.py" line="57"/>
-        <source>Répertoire pour les travaux :</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="Ui_preferences.py" line="56"/>
+        <location filename="../Ui_preferences.py" line="61"/>
         <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_copyToDialog1.py" line="172"/>
-        <source>Répertoire de destination des baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="Ui_preferences.py" line="58"/>
-        <source>Travail</source>
+        <location filename="../Ui_preferences.py" line="62"/>
+        <source>Répertoire pour les travaux :</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_copyToDialog1.py" line="174"/>
+        <location filename="../Ui_copyToDialog1.py" line="174"/>
+        <source>Choix des fichiers à copier</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_copyToDialog1.py" line="180"/>
+        <source>Répertoire de destination des baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_copyToDialog1.py" line="182"/>
         <source>Répertoire de destination sur les baladeurs,&lt;br&gt;peut être modifié dans les préférences</source>
         <translation type="unfinished"></translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_copyToDialog1.py" line="192"/>
+        <source>Taille totale :</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="216"/>
+        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="265"/>
+        <source>Aucun fichier sélectionné</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="259"/>
+        <source>Choix de fichiers à copier</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="260"/>
+        <source>Choix de fichiers à copier depuis les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="273"/>
+        <source>Choisir un répertoire de destination</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="292"/>
+        <source>Voulez-vous voir les fichiers copiés ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../copyToDialog1.py" line="165"/>
+        <source>%s méga-octets</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context encoding="UTF-8">
+    <name>Main</name>
+    <message encoding="UTF-8">
+        <location filename="../help.py" line="39"/>
+        <source>Version numéro %1.%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="318"/>
+        <source>Démontage des baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="318"/>
+        <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="422"/>
+        <source>Cocher ou décocher cette case en cliquant.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="424"/>
+        <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="426"/>
+        <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="428"/>
+        <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="430"/>
+        <source>Fabricant de la clé USB ou du baladeur.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="432"/>
+        <source>Modèle de la clé USB ou du baladeur.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="434"/>
+        <source>Numéro de série de la clé USB ou du baladeur.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="Ui_mainWindow.py" line="103"/>
-        <source>Actions</source>
-        <translation>Actions</translation>
+        <location filename="../Ui_diskFull.py" line="56"/>
+        <source>Disk size</source>
+        <translation>Taille du disque</translation>
     </message>
     <message>
-        <location filename="Ui_mainWindow.py" line="105"/>
+        <location filename="../Ui_mainWindow.py" line="126"/>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_diskFull.py" line="58"/>
+        <source>total size</source>
+        <translation>taille totale</translation>
+    </message>
+    <message>
+        <location filename="../Ui_diskFull.py" line="59"/>
+        <source>Used</source>
+        <translation>Utilisé(s)</translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="107"/>
+        <source>ScolaSync</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="108"/>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="110"/>
         <source>Copier depuis les cles</source>
         <translation>Copier depuis les clés</translation>
     </message>
     <message>
-        <location filename="Ui_mainWindow.py" line="121"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="Ui_mainWindow.py" line="108"/>
+        <location filename="../Ui_mainWindow.py" line="113"/>
         <source>Copier vers les cles</source>
         <translation>Copier vers les clés</translation>
     </message>
     <message>
-        <location filename="Ui_mainWindow.py" line="114"/>
+        <location filename="../Ui_mainWindow.py" line="119"/>
         <source>Demonter les cles</source>
         <translation>Démonter les clés</translation>
     </message>
     <message>
-        <location filename="Ui_mainWindow.py" line="120"/>
-        <source>Aide</source>
-        <translation>Aide</translation>
+        <location filename="../Ui_mainWindow.py" line="122"/>
+        <source>Preferences</source>
+        <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="Ui_mainWindow.py" line="102"/>
-        <source>ScolaSync</source>
-        <translation>ScolaSync</translation>
+        <location filename="../Ui_mainWindow.py" line="125"/>
+        <source>Aide</source>
+        <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="Ui_mainWindow.py" line="111"/>
+        <location filename="../Ui_mainWindow.py" line="116"/>
         <source>Supprimer dans les clés</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="Ui_diskFull.py" line="51"/>
-        <source>Disk size</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="Ui_diskFull.py" line="53"/>
-        <source>total size</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="Ui_diskFull.py" line="54"/>
-        <source>Used</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="Ui_mainWindow.py" line="117"/>
-        <source>Preferences</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context encoding="UTF-8">
     <name>diskFull</name>
     <message encoding="UTF-8">
-        <location filename="diskFull.py" line="55"/>
+        <location filename="../diskFull.py" line="55"/>
         <source>Place totale : %1 kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="diskFull.py" line="56"/>
+        <location filename="../diskFull.py" line="56"/>
         <source>Place utilisée : %1 kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context encoding="UTF-8">
-    <name>mainWindow</name>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="412"/>
-        <source>Cocher ou décocher cette case en cliquant.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="414"/>
-        <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="416"/>
-        <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="418"/>
-        <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="420"/>
-        <source>Fabricant de la clé USB ou du baladeur.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="422"/>
-        <source>Modèle de la clé USB ou du baladeur.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="424"/>
-        <source>Numéro de série de la clé USB ou du baladeur.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="help.py" line="39"/>
-        <source>Version numéro %1.%2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="308"/>
-        <source>Démontage des baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="mainWindow.py" line="308"/>
-        <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>uDisk</name>
     <message>
-        <location filename="ownedUsbDisk.py" line="152"/>
-        <source>inconnu</source>
-        <translation>** inconnu **</translation>
-    </message>
-    <message>
-        <location filename="ownedUsbDisk.py" line="193"/>
-        <source>Entrer un nom</source>
-        <translation>Entrer un nom</translation>
-    </message>
-    <message>
-        <location filename="ownedUsbDisk.py" line="192"/>
-        <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
-        <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
-    </message>
-    <message>
-        <location filename="usbDisk.py" line="65"/>
-        <source>vendeur</source>
-        <translation>vendeur</translation>
-    </message>
-    <message>
-        <location filename="usbDisk.py" line="64"/>
-        <source>taille</source>
-        <translation>taille</translation>
-    </message>
-    <message>
-        <location filename="usbDisk.py" line="63"/>
+        <location filename="../usbDisk.py" line="63"/>
         <source>point de montage</source>
-        <translation>point de montage</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="usbDisk.py" line="70"/>
+        <location filename="../usbDisk.py" line="64"/>
+        <source>taille</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../usbDisk.py" line="65"/>
+        <source>vendeur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../usbDisk.py" line="70"/>
         <source>cocher</source>
-        <translation>cocher</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ownedUsbDisk.py" line="136"/>
+        <location filename="../ownedUsbDisk.py" line="144"/>
         <source>owner</source>
-        <translation>Propriétaire</translation>
+        <translation>propriétaire</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="usbDisk.py" line="67"/>
-        <source>numéro de série</source>
+        <location filename="../usbDisk.py" line="66"/>
+        <source>modèle de disque</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="usbDisk.py" line="66"/>
-        <source>modèle de disque</source>
+        <location filename="../usbDisk.py" line="67"/>
+        <source>numéro de série</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
