@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-# 	$Id: mainWindow.py 43 2011-01-15 23:12:57Z georgesk $	
+# 	$Id: mainWindow.py 47 2011-06-13 10:20:14Z georgesk $	
 
 licence={}
 licence['en']="""
@@ -25,11 +25,14 @@ licence['en']="""
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-import ownedUsbDisk, help, copyToDialog1, deleteDialog, usbThread, preferences
-import chooseFromUsbDialog
-import os.path, operator, subprocess, dbus, re
+import ownedUsbDisk, help, copyToDialog1, chooseInSticks, usbThread, preferences
+import os.path, operator, subprocess, dbus, re, time
 from notification import Notification
 import db
+from globaldef import logFileName
+
+# cette donnée est globale, pour être utilisé depuis n'importe quel objet
+globalDiskData=ownedUsbDisk.Available(True,access="firstFat")
 
 def firstdir(l):
     """
@@ -53,6 +56,7 @@ def _dir(which):
         return firstdir(["/usr/share/scolasync/","share"])
     return None
 
+
 class mainWindow(QMainWindow):
     def __init__(self, parent, opts, locale="fr_FR"):
         """
@@ -87,23 +91,33 @@ class mainWindow(QMainWindow):
         """
         Applique les préférences et les options de ligne de commande
         """
+        global globalDiskData
         prefs=db.readPrefs()
         self.workdir=prefs["workdir"]
         # on active les cases à cocher si ça a été réclamé par les options
         # ou par les préférences
         self.checkable=("--check","") in self.opts or ("-c","") in self.opts or prefs["checkable"]
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        self.diskData=other
+        globalDiskData=other
         self.header=ownedUsbDisk.uDisk.headers(self.checkable)
         self.connectTableModel(other)
-        self.t.setSortingEnabled(False)
+        self.t.setSortingEnabled(True)
         self.t.resizeColumnsToContents()
 
+    def changeWd(self, newDir):
+        """
+        change le répertoire par défaut contenant les fichiers de travail
+        @param newDir le nouveau nom de répertoire
+        """
+        self.workdir=newDir
+        db.setWd(newDir)
+
     def tableClicked(self, idx):
         """
         fonction de rappel pour un double clic sur un élément de la table
         @param idx un QModelIndex
         """
+        global globalDiskData
         c=idx.column()
         r=idx.row()
         h=self.header[c]
@@ -117,7 +131,7 @@ class mainWindow(QMainWindow):
             cmd=u"nautilus '%s'" %idx.data().toString ()
             subprocess.call(cmd, shell=True)
         elif "device-size" in h:
-            path=self.diskData[r][self.header.index("1device-mount-paths")]
+            path=globalDiskData[r][self.header.index("1device-mount-paths")]
             cmd =u"df '%s'" %path
             dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0].split("\n")[-2]
             m = re.match("(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
@@ -129,8 +143,8 @@ class mainWindow(QMainWindow):
             w.show()
         else:
             QMessageBox.warning(None,
-                                       self.tr(u"Double-clic non pris en compte"),
-                                       self.tr(u"pas d'action pour l'attribut %s" %h))
+                                QApplication.translate("Dialog","Double-clic non pris en compte",None, QApplication.UnicodeUTF8),
+                                QApplication.translate("Dialog","pas d'action pour l'attribut %1",None, QApplication.UnicodeUTF8).arg(h))
 
     def diskFromTableRow(self,ligne):
         """
@@ -138,9 +152,10 @@ class mainWindow(QMainWindow):
         @param ligne la ligne du tableau qui concerne une clé
         @return le disque correspondant à la ligne de tableau (type uDisk)
         """
-        stickid=self.diskData[ligne][self.header.index("5drive-serial")]
+        global globalDiskData
+        stickid=globalDiskData[ligne][self.header.index("5drive-serial")]
         found=False
-        for d in self.diskData.disks.keys():
+        for d in globalDiskData.disks.keys():
             if d.showableProp("drive-serial")==stickid:
                 found=True
                 break
@@ -154,10 +169,11 @@ class mainWindow(QMainWindow):
         Édition du propriétaire d'une clé.
         @param ligne la ligne du tableau qui concerne une clé
         """
-        student=self.diskData[ligne][1]
+        global globalDiskData
+        student=globalDiskData[ligne][1]
         ownedUsbDisk.editRecord(self.diskFromTableRow(ligne), student)
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        self.diskData=other
+        globalDiskData=other
         self.connectTableModel(other)
         
     def updateButtons(self):
@@ -168,7 +184,8 @@ class mainWindow(QMainWindow):
         active. Par contre démonter les clés quand elles sont absentes ça
         n'a pas d'utilité.
         """
-        if len(self.diskData)>0:
+        global globalDiskData
+        if len(globalDiskData)>0:
             self.ui.toButton.setEnabled(True)
             self.ui.fromButton.setEnabled(True)
             self.ui.umountButton.setEnabled(True)
@@ -194,106 +211,92 @@ class mainWindow(QMainWindow):
         """
         Lance l'action de supprimer des fichiers ou des répertoires dans les clés USB
         """
-        d=deleteDialog.deleteDialog()
-        # on cherche à détecter la clé sélectionnée
-        # pour fournier un répertoire de choix au dialogue
-        sel=self.t.selectedIndexes()
-        i=0 # on prend la première ligne par défaut !
-        d.chooseDir=None
-        if len(sel)>0:
-            i=sel[0].row()
-        # on va essayer de tester la présence d'un répertoire de travail
-        cd=os.path.join(self.tm.donnees[i].ensureMounted(),
-                        self.tm.donnees[i].visibleDir(),
-                        self.workdir)
-        # "nettoyage" du chemin (on simplifie les "/./")
-        cd=os.path.abspath(cd)
-        if os.path.isdir(cd):
-            # dans le cas où le répertoire de travail est trouvé, on commence là.
-            d.chooseDir=cd
-            
+        global globalDiskData
+        titre1=QApplication.translate("Dialog","Choix de fichiers à supprimer",None, QApplication.UnicodeUTF8)
+        titre2=QApplication.translate("Dialog","Choix de fichiers à supprimer (jokers autorisés)",None, QApplication.UnicodeUTF8)
+        d=chooseInSticks.chooseDialog(self, titre1, titre2)
         ok = d.exec_()
         if ok:
             pathList=map(lambda x: u"%s" %x, d.pathList())
-            for p in self.diskData:
-                t=usbThread.threadDeleteInUSB(p,pathList,subdir="Travail", logfile="~/.scolasync/scolasync.log")
-                t.setDaemon(True)
-                self.threads.append(t)
-                t.start()
+            reply=QMessageBox.critical(None,
+                                       QApplication.translate("Dialog","Vous allez effacer plusieurs baladeurs",None, QApplication.UnicodeUTF8),
+                                       QApplication.translate("Dialog","Etes-vous certain de vouloir effacer : "+",".join(pathList),None, QApplication.UnicodeUTF8))
+            if reply == QMessageBox.Ok:
+                for p in globalDiskData:
+                    t=usbThread.threadDeleteInUSB(p,pathList,subdir="Travail", logfile=logFileName)
+                    t.setDaemon(True)
+                    self.threads.append(t)
+                    t.start()
         else:
             msgBox=QMessageBox.warning(None,
-                                       self.tr(u"Aucun fichier sélectionné"),
-                                       self.tr(u"Veuillez choisir au moins un fichier"))
+                                       QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
+                                       QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
 
     def copyTo(self):
         """
         Lance l'action de copier vers les clés USB
         """
-        d=copyToDialog1.copyToDialog1(workdir=self.workdir)
+        global globalDiskData
+        d=copyToDialog1.copyToDialog1(parent=self, workdir=self.workdir)
         d.exec_()
         if d.ok==True:
-            for p in self.diskData:
-                t=usbThread.threadCopyToUSB(p,d.selectedList(),subdir=self.workdir, logfile="~/.scolasync/scolasync.log")
+            for p in globalDiskData:
+                subdir=self.workdir
+                t=usbThread.threadCopyToUSB(p,d.selectedList(),subdir=subdir, logfile=logFileName)
                 t.setDaemon(True)
                 self.threads.append(t)
                 t.start()
         else:
             msgBox=QMessageBox.warning(None,
-                                       self.tr(u"Aucun fichier sélectionné"),
-                                       self.tr(u"Veuillez choisir au moins un fichier"))
+                                       QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
+                                       QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
 
     def copyFrom(self):
         """
         Lance l'action de copier depuis les clés USB
         """
-        d=chooseFromUsbDialog.chooseDialog()
-        # on cherche à détecter la clé sélectionnée
-        # pour fournier un répertoire de choix au dialogue
-        sel=self.t.selectedIndexes()
-        i=0 # on prend la première ligne par défaut !
-        d.chooseDir=None
-        if len(sel)>0:
-            i=sel[0].row()
-        # on va essayer de tester la présence d'un répertoire de travail
-        cd=os.path.join(self.tm.donnees[i].ensureMounted(),
-                        self.tm.donnees[i].visibleDir(),
-                        self.workdir)
-        # "nettoyage" du chemin (on simplifie les "/./")
-        cd=os.path.abspath(cd)
-        if os.path.isdir(cd):
-            # dans le cas où le répertoire de travail" est trouvé, on commence là.
-            d.chooseDir=cd
-            
+        global globalDiskData
+        titre1=QApplication.translate("Dialog","Choix de fichiers à copier",None, QApplication.UnicodeUTF8)
+        titre2=QApplication.translate("Dialog", "Choix de fichiers à copier depuis les baladeurs", None, QApplication.UnicodeUTF8)
+        ok=QApplication.translate("Dialog", "Choix de la destination ...", None, QApplication.UnicodeUTF8)
+        d=chooseInSticks.chooseDialog(self, title1=titre1, title2=titre2, ok=ok)
         ok = d.exec_()
         if not ok or len(d.pathList())==0 :
             msgBox=QMessageBox.warning(None,
-                                       self.tr(u"Aucun fichier sélectionné"),
-                                       self.tr(u"Veuillez choisir au moins un fichier"))
+                                       QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
+                                       QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
             return
         # bon, alors c'est OK pour le choix des fichiers à envoyer
         pathList=map(lambda x: u"%s" %x, d.pathList())
+        mp=d.selectedDiskMountPoint()
         initialPath=os.path.expanduser("~")
         destDir = QFileDialog.getExistingDirectory(None,
-                                                      self.tr(u"Choisir un répertoire de destination"),
-                                                      initialPath)
+                                                   QApplication.translate("Dialog","Choisir un répertoire de destination",None, QApplication.UnicodeUTF8),
+                                                   initialPath)
         if destDir and len(destDir)>0 :
             dest=u"%s" %destDir
-            for p in self.diskData:
+            for p in globalDiskData:
+                # on devrait vérifier s'il y a des données à copier
+                # et s'il n'y en a pas, ajouter des lignes au journal
+                # mais on va laisser faire ça dans le thread
+                # inconvénient : ça crée quelquefois des sous-répertoires
+                # vides inutiles dans le répertoire de destination.
                 t=usbThread.threadCopyFromUSB(p,pathList,subdir=self.workdir,
+                                              rootPath=mp,
                                               dest=dest,
-                                              logfile="~/.scolasync/scolasync.log")
+                                              logfile=logFileName)
                 t.setDaemon(True)
                 self.threads.append(t)
                 t.start()
             # on ouvre nautilus pour voir le résultat des copies
             if QMessageBox.question(None,
-                                    self.tr(u"Voir les copies"),
-                                    self.tr(u"Voulez-vous voir les fichiers copiés ?")):
-                subprocess.call("nautilus %s" %dest,shell=True)
+                                    QApplication.translate("Dialog","Voir les copies",None, QApplication.UnicodeUTF8),
+                                    QApplication.translate("Dialog","Voulez-vous voir les fichiers copiés ?",None, QApplication.UnicodeUTF8)):
+                subprocess.call("nautilus '%s'" %dest,shell=True)
         else:
             msgBox=QMessageBox.warning(None,
-                                       self.tr(u"Destination manquante"),
-                                       self.tr(u"Veuillez choisir une destination pour la copie des fichiers"))
+                                       QApplication.translate("Dialog","Destination manquante",None, QApplication.UnicodeUTF8),
+                                       QApplication.translate("Dialog","Veuillez choisir une destination pour la copie des fichiers",None, QApplication.UnicodeUTF8))
 
     
 
@@ -310,18 +313,21 @@ class mainWindow(QMainWindow):
         """
         Démonte et détache les clés USB affichées
         """
+        global globalDiskData
+        buttons=QMessageBox.StandardButtons(QMessageBox.Ok+QMessageBox.Cancel)
         button=QMessageBox.critical ( self,
-                                      QApplication.translate("mainWindow","Démontage des baladeurs",None, QApplication.UnicodeUTF8),
-                                      QApplication.translate("mainWindow","Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?",None, QApplication.UnicodeUTF8))
+                                      QApplication.translate("Main","Démontage des baladeurs",None, QApplication.UnicodeUTF8),
+                                      QApplication.translate("Main","Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?",None, QApplication.UnicodeUTF8),
+                                      buttons=buttons)
         if button!=QMessageBox.Ok:
             return
         # on parcourt les premières partition FAT
-        for p in self.diskData:
+        for p in globalDiskData:
             # on trouve leurs disques parents
-            for d in self.diskData.disks.keys():
-                if p in self.diskData.disks[d] and p.selected:
+            for d in globalDiskData.disks.keys():
+                if p in globalDiskData.disks[d] and p.selected:
                     # démontage de toutes les partitions du même disque parent
-                    for partition in self.diskData.disks[d]:
+                    for partition in globalDiskData.disks[d]:
                         devfile=partition.getProp("device-file-by-id")
                         if isinstance(devfile, dbus.Array):
                             devfile=devfile[0]
@@ -349,23 +355,23 @@ class mainWindow(QMainWindow):
         self.t.setModel(self.tm)
         if self.checkable:
             self.t.setItemDelegateForColumn(0, CheckBoxDelegate(self))
+            self.t.setItemDelegateForColumn(1, UsbDiskDelegate(self))
         else:
-            # unset the special delegate !!!
-            self.t.setItemDelegateForColumn(0, QStyledItemDelegate(self))
+            self.t.setItemDelegateForColumn(0, UsbDiskDelegate(self))
         
     def checkDisks(self):
+        """
+        fonction relancée périodiquement pour vérifier s'il y a un changement
+        dans le baladeurs, et signaler dans le tableau les threads en cours.
+        Le tableau est complètement régénéré à chaque fois, ce qui n'est pas
+        toujours souhaitable.
+        """
+        global globalDiskData
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        test=self.diskData.compare(other)
-        if not test:
-            Notification(summary=u"%s" %self.tr(u"Liste de périphériques modifiée pour Scolasync"),
-                         app_icon="/usr/share/scolasync/images/scolasync.png",
-                         body=u"%s" %self.tr(u"Une clé USB ou un baladeur numérique au moins a change de statut. Vérifiez éventuellement la liste des périphériques de Scolasync"),
-                         replaces_id=1111,
-                         expire_timeout=5000).notify()
-            self.diskData=other
-            self.connectTableModel(other)
-            self.updateButtons()
-            self.t.resizeColumnsToContents()
+        globalDiskData=other
+        self.connectTableModel(other)
+        self.updateButtons()
+        self.t.resizeColumnsToContents()
 
 
 
@@ -400,7 +406,6 @@ class usbTableModel(QAbstractTableModel):
         return len(self.header) 
 
     def setData(self, index, value, role):
-        #if index.column()==0 and role==Qt.DisplayRole:
         if index.column()==0 and self.checkable:
             self.donnees[index.row()].selected=value
             return True
@@ -414,19 +419,19 @@ class usbTableModel(QAbstractTableModel):
             c=index.column()
             h=self.pere.header[c]
             if c==0 and self.checkable:
-                return QApplication.translate("mainWindow","Cocher ou décocher cette case en cliquant.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Cocher ou décocher cette case en cliquant.",None, QApplication.UnicodeUTF8)
             elif c==1:
-                return QApplication.translate("mainWindow","Propriétaire de la clé USB ou du baladeur ;<br><b>Double-clic</b> pour modifier.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Propriétaire de la clé USB ou du baladeur ;<br><b>Double-clic</b> pour modifier.",None, QApplication.UnicodeUTF8)
             elif "device-mount-paths" in h:
-                return QApplication.translate("mainWindow","Point de montage de la clé USB ou du baladeur ;<br><b>Double-clic</b> pour voir les fichiers.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Point de montage de la clé USB ou du baladeur ;<br><b>Double-clic</b> pour voir les fichiers.",None, QApplication.UnicodeUTF8)
             elif "device-size" in h:
-                return QApplication.translate("mainWindow","Capacité de la clé USB ou du baladeur en kO ;<br><b>Double-clic</b> pour voir la place occupée.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Capacité de la clé USB ou du baladeur en kO ;<br><b>Double-clic</b> pour voir la place occupée.",None, QApplication.UnicodeUTF8)
             elif "drive-vendor" in h:
-                return QApplication.translate("mainWindow","Fabricant de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Fabricant de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
             elif "drive-model" in h:
-                return QApplication.translate("mainWindow","Modèle de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Modèle de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
             elif "drive-serial" in h:
-                return QApplication.translate("mainWindow","Numéro de série de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
+                return QApplication.translate("Main","Numéro de série de la clé USB ou du baladeur.",None, QApplication.UnicodeUTF8)
             else:
                 return ""
         elif role != Qt.DisplayRole: 
@@ -491,3 +496,26 @@ class CheckBoxDelegate(QStyledItemDelegate):
         return result
 
         
+class UsbDiskDelegate(QStyledItemDelegate):
+    def __init__(self, parent):
+        QStyledItemDelegate.__init__(self,parent)
+        self.okPixmap=QPixmap("/usr/share/icons/Tango/16x16/status/weather-clear.png")
+        self.busyPixmap=QPixmap("/usr/share/icons/Tango/16x16/actions/view-refresh.png")
+
+    def paint(self, painter, option, index):
+        global globalDiskData
+        text = index.model().data(index, Qt.DisplayRole).toString()
+        rect0=QRect(option.rect)
+        rect1=QRect(option.rect)
+        h=rect0.height()
+        w=rect0.width()
+        rect0.setSize(QSize(h,h))
+        rect1.translate(h,0)
+        rect1.setSize(QSize(w-h,h))
+        QApplication.style().drawItemText (painter, rect1, Qt.AlignLeft+Qt.AlignVCenter, option.palette, True, text)
+        QApplication.style().drawItemText (painter, rect0, Qt.AlignCenter, option.palette, True, QString("O"))
+        if usbThread.globalThreads.busy(u"%s" %text):
+            QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.busyPixmap)
+        else:
+            QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.okPixmap)
+        
